//
//  ClipsViewController.m
//  igroup
//

#import "ClipsViewController.h"
#import "PlayEditViewController.h"

@class Song;
@class Clip;
@class RoutineViewController;


@implementation ClipsViewController

@synthesize tableView;
@synthesize mySong, cutNewClipButton;

- (void)viewDidLoad {
    [super viewDidLoad];
	self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)viewWillAppear:(BOOL)animated {
	self.navigationItem.title = mySong.title;
	[self.tableView reloadData];
}

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}

- (IBAction)cutClip {
	Clip *newClip = [[Clip alloc] initWithSong:mySong];
	newClip.name = [NSString stringWithFormat:@"%@ Clip #%u", mySong.title, [mySong.clips count]];
	[mySong.clips addObject:newClip];
	
	PlayEditViewController *pevController = [[PlayEditViewController alloc] initWithNibName:@"PlayEditViewController" bundle:nil];
	pevController.clip = newClip;
	[self presentModalViewController:pevController animated:YES];
	[pevController release];
}

#pragma mark Table view methods

- (NSInteger)numberOfSectionsInTableView:(UITableView *)aTableView {
    return 1;
}

- (NSInteger)tableView:(UITableView *)aTableView numberOfRowsInSection:(NSInteger)section {
    return [mySong.clips count];
	
}

- (UITableViewCell *)tableView:(UITableView *)aTableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [aTableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier] autorelease];
    }
	
	Clip *currentClip = [mySong.clips objectAtIndex:indexPath.row]; 
	cell.textLabel.text = currentClip.name; 
	cell.detailTextLabel.text = [NSString stringWithFormat:@"Start: %02u:%02u  End: %02u:%02u", ((NSUInteger) currentClip.start /60), ((NSUInteger) currentClip.start%60), ((NSUInteger) currentClip.end/60), ((NSUInteger) currentClip.end%60)]; 	

	return cell;
}


- (void)tableView:(UITableView *)aTableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    // Navigation logic may go here. Create and push another view controller.
	
	NSArray *vControllersStack = [self.navigationController viewControllers];
	NSLog(@"%d", [vControllersStack count]);
	Clip *selectedClip = [mySong.clips objectAtIndex:indexPath.row];
	if ([vControllersStack count] > 3) {
		UIViewController *routineVC = [vControllersStack objectAtIndex:([vControllersStack count] - 3)];
		[routineVC fetchClip:selectedClip];
		[self.navigationController popToViewController:routineVC animated:YES];
	} else {
		PlayEditViewController *pevController = [[PlayEditViewController alloc] initWithNibName:@"PlayEditViewController" bundle:nil];
		pevController.clip = selectedClip;
		[[aTableView cellForRowAtIndexPath:indexPath] setHighlighted:NO animated:YES];
		[self presentModalViewController:pevController animated:YES];
		[pevController release];
	}
}

- (void)setEditing:(BOOL)editing animated:(BOOL)animate {
	tableView.editing = editing;
	
	[super setEditing:editing animated:animate];
}

- (void)tableView:(UITableView *)aTableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
		NSLog(@"Deleting a row now");
		[mySong.clips removeObjectAtIndex:indexPath.row]; 
        [aTableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:YES];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}

- (void)tableView:(UITableView *)aTableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath {
	NSUInteger fromPosition = [fromIndexPath row];
	NSUInteger toPosition = [toIndexPath row]; 
	NSMutableArray *allClips = mySong.clips; 
	Clip *rClip = [allClips objectAtIndex:fromPosition];
	[allClips insertObject:rClip atIndex:toPosition]; 
	if(toPosition < fromPosition) {
		fromPosition++; 
	}
	[allClips removeObjectAtIndex:fromPosition]; 
}

- (void)dealloc {
    [super dealloc];
}


@end
