//
//  PlayEditViewController.m
//  igroup
//

#import "PlayEditViewController.h"


@implementation PlayEditViewController

@synthesize clipEditSlider, clipEditSliderViewController;
@synthesize clipStartTimeLabel, clipEndTimeLabel;
@synthesize clipName;
@synthesize songTitleLabel;
@synthesize artistNameLabel;
@synthesize clipCurrentTimeLabel, clipTimeLeftLabel;
@synthesize repeatButton, playButton, saveButton;
@synthesize pointer;
@synthesize clip;
@synthesize songMediaItem;
@synthesize textfield;
@synthesize playbackTimer;

static NSString *timeLabelFormat = @"%02u:%02u";

/** This should load after a clip is set. */
- (void)viewDidLoad {
    [super viewDidLoad];
	
	[self addClipEditSliderToView];
	
	/* Load song metadata info in view. */
	clipName.title = clip.name;
#if TARGET_CPU_ARM
	songTitleLabel.text = [songMediaItem valueForProperty:MPMediaItemPropertyTitle];
	artistNameLabel.text = [songMediaItem valueForProperty:MPMediaItemPropertyArtist];
#endif
	
	/* Set slider values. */
	clipEditSlider.minimumValue = 0.0;
#if TARGET_CPU_ARM
	clipEditSlider.maximumValue = [[songMediaItem valueForProperty:MPMediaItemPropertyPlaybackDuration] doubleValue];
#else
	clipEditSlider.maximumValue = 400.0;
#endif
	clipEditSlider.valueLeft = clip.start;
	clipEditSlider.valueRight = clip.end;
	
	[self updateClipTimeLabels];
	[self updatePlaybackState];
	[self movePointerToTime:clip.start];
}

- (void)addClipEditSliderToView {
	self.clipEditSliderViewController = [[ClipEditSliderViewController alloc] initWithNibName:@"ClipEditSlider" bundle:nil];
	[clipEditSliderViewController release];
	self.clipEditSlider = (ClipEditSlider *) clipEditSliderViewController.view;
	
	CGSize size = clipEditSlider.bounds.size;
	trackMinX = (480.0 - clipEditSlider.frame.size.width) / 2;
	clipEditSlider.frame = CGRectMake(trackMinX, 180.0, size.width, size.height);
	trackMaxX = trackMinX + size.width;
	
	[clipEditSlider addTarget:self action:@selector(clipEditSliderDidChange:) forControlEvents:UIControlEventValueChanged];
	
	[self.view addSubview:clipEditSlider];
}

- (IBAction)backToSongs:(id)sender {
#if TARGET_CPU_ARM	
	[[MPMusicPlayerController applicationMusicPlayer] stop];
#endif
	[self dismissModalViewControllerAnimated:YES];
}

- (IBAction)playButtonPressed:(id)sender {
	MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
	if (player.playbackState == MPMusicPlaybackStatePlaying) {
		[self pause];
	} else {
		player.currentPlaybackTime = clip.start;
		[self play];
	}
}

- (IBAction)save:(id)sender {

}

- (IBAction)editName:(id)sender { 
	UIAlertView *myAlertView = [[UIAlertView alloc] initWithTitle:@"Rename Clip" message:@"this gets covered" delegate:self cancelButtonTitle:@"Cancel" otherButtonTitles:@"Save", nil];
	textfield = [[UITextField alloc] initWithFrame:CGRectMake(12.0, 45.0, 260.0, 25.0)];
	[textfield setBackgroundColor:[UIColor whiteColor]];
	textfield.text = clip.name;
	textfield.returnKeyType = UIReturnKeyDone; 
	[myAlertView addSubview:textfield];
	CGAffineTransform myTransform = CGAffineTransformMakeTranslation(0.0, 80.0);
	[myAlertView setTransform:myTransform];
	[textfield becomeFirstResponder]; 
	[myAlertView show];
	[myAlertView release];	
}

- (void)alertView:(UIAlertView *)actionSheet clickedButtonAtIndex:(NSInteger)buttonIndex {
	clip.name = textfield.text;
	clipName.title = clip.name;
}

- (IBAction)repeat:(id)sender {
	
}

- (void)play {
	MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
	
	self.playbackTimer = [NSTimer scheduledTimerWithTimeInterval:1.0 target:self selector:@selector(updatePlaybackState) userInfo:nil repeats:YES];
	[player play];
	[playButton	setImage:[UIImage imageNamed:@"pause_icon.png"]];
}

- (void)pause {
	MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
	
	[playbackTimer invalidate];
	[player pause];
	[playButton setImage:[UIImage imageNamed:@"play_icon.png"]];
}

/** Overrides clip's setter. */
- (void)setClip:(Clip *)aClip {
	if (aClip != clip) {
		[clip release];
		clip = [aClip retain];
		
#if TARGET_CPU_ARM
		self.songMediaItem = clip.parent.songMediaItem;
		
		/* Set up music player to play this media item. */
		MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
		MPMediaItemCollection *mediaItemCollection = [MPMediaItemCollection collectionWithItems:[NSArray arrayWithObject:self.songMediaItem]];
		[player setQueueWithItemCollection:mediaItemCollection];
#endif
	}
}

- (void)clipEditSliderDidChange:(id)sender {
	/* Update clip. */
	clip.start = clipEditSlider.valueLeft;
	clip.end = clipEditSlider.valueRight;

#if TARGET_CPU_ARM
	/* Update player. */
	MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
	player.currentPlaybackTime = clip.start;
#endif
	
	/* Update view. */
	[self updateClipTimeLabels];
	[self updatePlaybackState];
	
	[self movePointerToTime:clip.start];
}

- (void)updateClipTimeLabels {
	NSUInteger startTime = clipEditSlider.valueLeft;
	NSUInteger endTime = clipEditSlider.valueRight;
	clipStartTimeLabel.text = [NSString stringWithFormat:timeLabelFormat, startTime / 60, startTime % 60];
	clipEndTimeLabel.text = [NSString stringWithFormat:timeLabelFormat, endTime / 60, endTime % 60];
}

- (void)updatePlaybackState {
#if TARGET_CPU_ARM
	MPMusicPlayerController *player = [MPMusicPlayerController applicationMusicPlayer];
	
	if (player.currentPlaybackTime >= clip.end) {
		[self pause];
		return;
	}
	
	NSUInteger currentTime = player.currentPlaybackTime - clip.start;
	NSUInteger timeLeft = clipEditSlider.valueRight - player.currentPlaybackTime;
	clipCurrentTimeLabel.text = [NSString stringWithFormat:timeLabelFormat, currentTime / 60, currentTime % 60];
	clipTimeLeftLabel.text = [NSString stringWithFormat:[NSString stringWithFormat:@"-%@", timeLabelFormat], timeLeft / 60, timeLeft % 60];
	
	[self movePointerToTime:player.currentPlaybackTime];
#endif
}

- (void)movePointerToTime:(double)time {
	double pointerPercent = time / (clipEditSlider.maximumValue - clipEditSlider.minimumValue);
	pointer.center = CGPointMake(trackMinX + (pointerPercent * (trackMaxX - trackMinX)), pointer.center.y);
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return UIInterfaceOrientationIsLandscape(interfaceOrientation);
}

- (void)viewDidUnload {
	[clip release];
	[songMediaItem release];
	[clipEditSlider release];
	[clipEditSliderViewController release];
}

- (void)dealloc {
    [super dealloc];
}

@end
